@@ -1,4 +1,4 @@
-# Copyright (c) 2018, DjaoDjin inc.
+# Copyright (c) 2022, DjaoDjin inc.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -26,11 +26,9 @@
 URLs for djaodjin-survey Django app
 """
 
-from django.conf.urls import include, url
+from ..compat import include, re_path
 
 urlpatterns = [
-    url(r'^api/', include('survey.urls.api')),
-    url(r'^manage/', include('survey.urls.manager')),
-    url(r'^matrix/', include('survey.urls.matrix')),
-    url(r'^', include('survey.urls.sample')),
+    re_path(r'^api/', include('survey.urls.api')),
+    re_path(r'^', include('survey.urls.views')),
 ]
